<?php
/**
 * atlas functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package atlas
 */

if ( ! function_exists( 'atlas_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function atlas_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on atlas, use a find and replace
		 * to change 'atlas' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'atlas', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

         // Add menus.
        register_nav_menus( array(
        'primary' => __( 'Primary Menu', 'atlas' ),

		
		
    ) );
		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'atlas_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'atlas_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function atlas_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'atlas_content_width', 640 );
}
add_action( 'after_setup_theme', 'atlas_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function atlas_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'atlas' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'atlas' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
	
	    register_sidebar( array(
        'name' => __( 'İletişim formu 1', 'atlas' ),
        'id' => 'contact_form',
        'description' => 'Contact form 7 eklentisi iletişim formu kısa kodunu buraya metin widgetini sürükleyin ve içine yapıştırın',
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widgettitle">',
        'after_title' => '</h3>'
    ) );
	
	
		 register_sidebar( array(
        'name' => __( 'Alt Bilgi Alanı 1', 'atlas' ),
        'id' => 'footer_widget_1',
        'description' => '',
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widgettitle">',
        'after_title' => '</h3>'
    ) );
	
		register_sidebar( array(
        'name' => __( 'Alt Bilgi Alanı 2', 'atlas' ),
        'id' => 'footer_widget_2',
        'description' => '',
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widgettitle">',
        'after_title' => '</h3>'
    ) );
	
		register_sidebar( array(
        'name' => __( 'Alt Bilgi Alanı 3', 'atlas' ),
        'id' => 'footer_widget_3',
        'description' => '',
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widgettitle">',
        'after_title' => '</h3>'
    ) );
	
		register_sidebar( array(
        'name' => __( 'Alt Bilgi Alanı 4', 'atlas' ),
        'id' => 'footer_widget_4',
        'description' => '',
        'before_widget' => '<li id="%1$s" class="widget %2$s">',
        'after_widget' => '</li>',
        'before_title' => '<h3 class="widgettitle">',
        'after_title' => '</h3>'
    ) );

}
add_action( 'widgets_init', 'atlas_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function atlas_scripts() {
	
	
	  /* JS */

    wp_enqueue_script( 'jquery' );
    wp_enqueue_script( 'jquery', get_template_directory_uri() . '/js/jquery.min.js', false, null, false);
    wp_enqueue_script( 'jquerymigrate', get_template_directory_uri() . '/js/jquery.migrate.js', false, null, false);
    wp_enqueue_script( 'jquerybxslider', get_template_directory_uri() . '/js/jquery.bxslider.min.js', false, null, false);
    wp_enqueue_script( 'jquerymagnificpopup', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', false, null, false);
    wp_enqueue_script( 'owlcarousel', get_template_directory_uri() . '/js/owl.carousel.min.js', false, null, false);
    wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', false, null, false);
    wp_enqueue_script( 'jqueryimagesloaded', get_template_directory_uri() . '/js/jquery.imagesloaded.min.js', false, null, false);
    wp_enqueue_script( 'jqueryisotope', get_template_directory_uri() . '/js/jquery.isotope.min.js', false, null, false);
    wp_enqueue_script( 'retina', get_template_directory_uri() . '/js/retina-1.1.0.min.js', false, null, false);
    wp_enqueue_script( 'pluginsscroll', get_template_directory_uri() . '/js/plugins-scroll.js', false, null, false);
    wp_enqueue_script( 'jquerythemepunchtools', get_template_directory_uri() . '/js/jquery.themepunch.tools.min.js', false, null, false);
    wp_enqueue_script( 'jquerythemepunchrevolution', get_template_directory_uri() . '/js/jquery.themepunch.revolution.min.js', false, null, false);
	wp_enqueue_script( 'atlas-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
	wp_enqueue_script( 'atlas-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );
    wp_enqueue_script( 'script', get_template_directory_uri() . '/js/script.js', false, null, false);

     /* STYLE */
	wp_enqueue_style( 'atlas-style', get_stylesheet_uri() );
    wp_enqueue_style( 'style-1', 'http://fonts.googleapis.com/css?family=Roboto:400,400italic,500,500italic,700,900,300', false, null, 'all');
    wp_enqueue_style( 'style-2', 'http://fonts.googleapis.com/css?family=Dancing+Script:400,700', false, null, 'all');
    wp_enqueue_style( 'fontawesome', '//maxcdn.bootstrapcdn.com/font-awesome/4.2.0/css/font-awesome.min.css', false, null, 'all');
    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css', false, null, 'screen');
    wp_enqueue_style( 'jquerybxslider', get_template_directory_uri() . '/css/jquery.bxslider.css', false, null, 'screen');
    wp_enqueue_style( 'magnificpopup', get_template_directory_uri() . '/css/magnific-popup.css', false, null, 'screen');
    wp_enqueue_style( 'owlcarousel', get_template_directory_uri() . '/css/owl.carousel.css', false, null, 'screen');
    wp_enqueue_style( 'owltheme', get_template_directory_uri() . '/css/owl.theme.css', false, null, 'screen');
    wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/css/font-awesome.css', false, null, 'screen');
    wp_enqueue_style( 'animate', get_template_directory_uri() . '/css/animate.css', false, null, 'screen');
    wp_enqueue_style( 'settings', get_template_directory_uri() . '/css/settings.css', false, null, 'screen');
    wp_enqueue_style( 'style', get_template_directory_uri() . '/css/style.css', false, null, 'screen');


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'atlas_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/breadcrumbs/breadcrumbs.php';
/**
 * Implement the Navwalker feature.            
 */
require get_template_directory() . '/inc/bootstrap/wp_bootstrap_navwalker.php';
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';
/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';
/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer-copyright.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer-home.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer-info.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}
	
